@@ -45,14 +45,14 @@ class DephyDevice:
 
         self.fields: List = []
         self.deviceId: int = self.INVALID_DEVICE.value
-        self.hasHabs: bool = False
-        self.isChiral: bool = False
+        self._hasHabs: bool = False
+        self._isChiral: bool = False
         self.streamingFrequency: int = 0
         self.heartbeatPeriod: int = 0
         self.useSafety: bool = False
         self._deviceName: str = ""
         self._deviceSide: str = ""
-        self._closed: bool = False
+        self._closed: bool = True
 
         self._clib = fxu.load_clib(self.cLibVersion, libFile=self.libFile)
 
@@ -99,7 +99,7 @@ class DephyDevice:
         if self._clib.get_device_name(self.deviceId, deviceName) != self.SUCCESS.value:
             raise RuntimeError("Could not get device name.")
 
-        return deviceName.value.decode("utf8")
+        return deviceName.value.decode("utf8").lower()
 
     # -----
     # deviceSide
@@ -121,12 +121,12 @@ class DephyDevice:
         deviceSide = (c.c_char * maxDeviceSideLength)()
 
         if self._clib.get_side(self.deviceId, deviceSide) != self.SUCCESS.value:
-            raise RuntimeError("Could not get device name.")
+            raise RuntimeError("Could not get device side.")
 
         side = deviceSide.value.decode("utf8")
 
         # If side isn't applicable (for, e.g., an actpack), string is empty
-        return side if side else "undefined"
+        return side.lower() if side else "undefined"
 
     # -----
     # open
@@ -188,7 +188,6 @@ class DephyDevice:
         self._deviceName = self.deviceName
         self._deviceSide = self.deviceSide
 
-        print("Check hasHabs to make sure correct device name is present.")
         if self._deviceName in fxe.hasHabs:
             self.hasHabs = True
 
@@ -258,7 +257,7 @@ class DephyDevice:
         for i in range(nLabels.value):
             for j in range(maxFieldLength):
                 fields[i] += labels[i][j].decode("utf8")
-            fields[i].strip("\x00")
+            fields[i] = fields[i].strip("\x00")
 
         return fields
 
@@ -416,9 +415,11 @@ class DephyDevice:
         """
         maxDataElements = self._clib.get_max_data_elements()
         nFields = c.c_int()
-        deviceData = (c.POINTER(c.c_uint32) * maxDataElements)()
+        deviceData = (c.c_int32 * maxDataElements)()
 
-        retCode = self._clib.read(self.deviceId, deviceData, c.byref(nFields))
+        retCode = self._clib.read(
+            self.deviceId, c.cast(deviceData, c.POINTER(c.c_int32)), c.byref(nFields)
+        )
 
         if retCode != self.SUCCESS.value:
             raise RuntimeError("Could not read from device.")
@@ -428,7 +429,7 @@ class DephyDevice:
         except AssertionError as err:
             raise AssertionError("Incorrect number of fields read.") from err
 
-        data = [deviceData[i].value for i in range(nFields.value)]
+        data = [deviceData[i] for i in range(nFields.value)]
 
         return dict(zip(self.fields, data))
 
@@ -455,11 +456,11 @@ class DephyDevice:
             by the field name.
         """
         qs = self.queueSize
-        data = (c.POINTER(c.c_uint32) * qs)()
+        data = (c.POINTER(c.c_int32) * qs)()
         nElements = c.c_int()
 
         for i in range(qs):
-            data[i] = (c.c_uint32 * len(self.fields))()
+            data[i] = (c.c_int32 * len(self.fields))()
 
         self._clib.read_all(self.deviceId, data, c.byref(nElements))
 
@@ -513,8 +514,12 @@ class DephyDevice:
             Command failed.
         """
         devId = self.deviceId
-        if self._clib.set_gains(devId, kp, ki, kd, k, b, ff) != self.SUCCESS.value:
-            raise RuntimeError("Command failed")
+        # There is a bug where, sometimes, the gains aren't set, so we try multiple
+        # times
+        for _ in range(5):
+            if self._clib.set_gains(devId, kp, ki, kd, k, b, ff) != self.SUCCESS.value:
+                raise RuntimeError("Command failed")
+            sleep(0.001)
 
     # -----
     # command_motor_position
@@ -539,7 +544,7 @@ class DephyDevice:
             self._clib.send_motor_command(devId, controller, value)
             != self.SUCCESS.value
         ):
-            raise RuntimeError("Coult not command motor position.")
+            raise RuntimeError("Could not command motor position.")
 
     # -----
     # command_motor_current
@@ -564,7 +569,7 @@ class DephyDevice:
             self._clib.send_motor_command(devId, controller, value)
             != self.SUCCESS.value
         ):
-            raise RuntimeError("Coult not command motor current.")
+            raise RuntimeError("Could not command motor current.")
 
     # -----
     # command_motor_voltage
@@ -589,7 +594,7 @@ class DephyDevice:
             self._clib.send_motor_command(devId, controller, value)
             != self.SUCCESS.value
         ):
-            raise RuntimeError("Coult not command motor voltage.")
+            raise RuntimeError("Could not command motor voltage.")
 
     # -----
     # command_motor_impedance
@@ -616,7 +621,7 @@ class DephyDevice:
             self._clib.send_motor_command(devId, controller, value)
             != self.SUCCESS.value
         ):
-            raise RuntimeError("Coult not command motor impedance.")
+            raise RuntimeError("Could not command motor impedance.")
 
     # -----
     # stop_motor
@@ -690,8 +695,10 @@ class DephyDevice:
 
         returnCode = self._clib.activate_bootloader(self.deviceId, targetCode)
 
+        if returnCode == self.INVALID_DEVICE.value:
+            raise RuntimeError(f"Invalid device ID for: `{target}`.")
         if returnCode != self.SUCCESS.value:
-            raise RuntimeError(f"Could not activate bootloader for: `{target}`.")
+            raise IOError
 
     # -----
     # bootloaderActive
@@ -754,7 +761,7 @@ class DephyDevice:
             "re": fxu.decode(fw.re),
         }
 
-        if self.hasHabs:
+        if self._hasHabs:
             fwDict["habs"] = fxu.decode(fw.habs)
 
         return fwDict
@@ -913,3 +920,21 @@ class DephyDevice:
 
         if self._clib.calibrate_imu(self.deviceId) != self.SUCCESS.value:
             raise RuntimeError("Could not calibrate imu.")
+
+    # -----
+    # hasHabs
+    # -----
+    @property
+    def hasHabs(self) -> bool:
+        if self._deviceName:
+            return self._hasHabs
+        raise RuntimeError("Must call open before checking hasHabs.")
+
+    # -----
+    # isChiral
+    # -----
+    @property
+    def isChiral(self) -> bool:
+        if self._deviceName:
+            return self._isChiral
+        raise RuntimeError("Must call open before checking isChiral.")
